@@ -27,35 +27,37 @@ Block Read/Write/Filter Functions
 """
 
 from contextlib import contextmanager
+import logging
+
+from . import path
+
+# initialize the paths
+try:
+    path.find()
+except Exception as e:
+    logging.warn(str(e))
+
+
+from . import ffmpegprocess
 
 from .utils.log import FFmpegError
 from .utils.filter import FilterGraph
 from .transcode import transcode
 from . import caps, probe, audio, image, video, media
-from . import ffmpegprocess
-from . import ffmpeg as _ffmpeg
 from . import streams as _streams
 
-__all__ = [
-    "transcode",
-    "caps",
-    "probe",
-    "set_path",
-    "audio",
-    "image",
-    "video",
-    'media',
-    "open",
-    "ffmpegprocess",
-    "FFmpegError",
-    "FilterGraph",
-]
-__version__ = "0.3.3"
+# fmt:off
+__all__ = ["ffmpeg_info", "get_path", "set_path", "is_ready", "transcode", "caps",
+    "probe", "audio", "image", "video", "media", "open", "ffmpegprocess",
+    "FFmpegError", "FilterGraph"]
+# fmt:on
 
-ffmpeg_info = _ffmpeg.versions
-set_path = _ffmpeg.find
-get_path = _ffmpeg.where
-is_ready = _ffmpeg.found
+__version__ = "0.4.0"
+
+ffmpeg_info = ffmpegprocess.versions
+set_path = path.find
+get_path = path.where
+is_ready = path.found
 
 
 @contextmanager
